#
# spec file for package python-lesscpy
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           python-lesscpy
Version:        0.15.1
Release:        2.4
Summary:        Lesscss compiler
License:        MIT
URL:            https://github.com/lesscpy/lesscpy
Source:         https://files.pythonhosted.org/packages/source/l/lesscpy/lesscpy-%{version}.tar.gz
# https://github.com/lesscpy/lesscpy/pull/126
Patch0:         python-lesscpy-no-six.patch
BuildRequires:  %{python_module ply}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module setuptools}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-ply
Requires:       python-setuptools
Requires(post): update-alternatives
Requires(postun):update-alternatives
BuildArch:      noarch
%python_subpackages

%description
python LessCss Compiler.

A compiler written in python 3 for the lesscss language.
For those of us not willing/able to have node.js installed in our environment.
Not all features of lesscss are supported (yet).
Some features wil probably never be supported (JavaScript evaluation).
This program uses PLY (Python Lex-Yacc) to tokenize/parse the input.

%prep
%autosetup -p1 -n lesscpy-%{version}
# remove failing tests, which rely on find_and_load_cases
rm test/test_{bootstrap3,less,issues}.py

%build
%python_build

%install
%python_install
%python_clone -a %{buildroot}%{_bindir}/lesscpy
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%post
%python_install_alternative lesscpy

%postun
%python_uninstall_alternative lesscpy

%check
%pytest

%files %{python_files}
%license LICENSE
%doc README.rst
%python_alternative %{_bindir}/lesscpy
%{python_sitelib}/lesscpy
%{python_sitelib}/lesscpy-%{version}-py*.egg-info

%changelog
* Mon Oct  2 2023 pgajdos@suse.com
- do not require six in the code
- added patches
  fix https://github.com/lesscpy/lesscpy/pull/126
  + python-lesscpy-no-six.patch
* Fri Oct 28 2022 Yogalakshmi Arunachalam <yarunachalam@suse.com>
- Update to v0.15.1
  * Git: Ignore '.DS_Store' (macOS)
  * Add `dev-requirements.txt` for `build` and `twine` packages
  * README: Remove mentioning of 'six'
  * Merge pull request #123 from saschpe/supported-interpreters
  * Update supported Python versions
* Thu Sep 29 2022 Yogalakshmi Arunachalam <yarunachalam@suse.com>
- Release version 0.15.0
  * Update .gitignore
  * Remove old interpreter versions
  * Merge pull request #118 from lephe/master
  * Improve support for nested media queries
  * Merge pull request #117 from lephe/master
  * Basic support for CSS4 variables
  * Merge pull request #109 from saschpe/rel
- Release version 0.14.0
  * Merge pull request #108 from saschpe/pycharm
  * Version a PyCharm project configuration
  * Update .gitignore rules based on Github Boilerplate
  * Merge pull request #107 from saschpe/cleanups
  * Add Python-3.7 to supported versions
  * Improve minor style issues
  * Merge pull request #105 from tirkarthi/fix-collections-import
  * Import ABC from collections.abc instead of collections for Python 3.9 compatibility.
  * Merge pull request #99 from hroncok/rpartition
  * Merge pull request #98 from movermeyer/fix_badges
  * Merge pull request #100 from cladmi/pr/fix/readme/command
  * README.rst: fix the outdated lesscpy usage
  * Apply PEP-8 consistently
  * Allow to run tests from versioned folder
  * Switched broken pypip.in badges to shields.io
  * Merge pull request #96 from sambler/pyversions
  * Merge pull request #97 from sambler/pysix
  * adjust tox.ini to prevent errors from missing interpreters
  * Make use of six.string_types consistent
  * update python versions 2.6 was EOL in 2013 3.3 was EOL in 2017-09 add 3.6, pypy and pypy3
* Wed Apr 15 2020 pgajdos@suse.com
- version update to 0.14.0
  * no upstream changelog found
* Mon Oct 14 2019 Matej Cepl <mcepl@suse.com>
- Replace %%fdupes -s with plain %%fdupes; hardlinks are better.
* Thu Feb 28 2019 John Vandenberg <jayvdb@gmail.com>
- Fix incorrect URL
- Remove unnecessary build dependencies on flake8 and coverage by
  using nose directly
- Add fdupes
- Update to v0.13.0
  Version bump due to non-linear version sequences
  https://github.com/lesscpy/lesscpy/issues/94
  No changelog available
* Tue Dec  4 2018 Matej Cepl <mcepl@suse.com>
- Remove superfluous devel dependency for noarch package
* Thu Aug 31 2017 toddrme2178@gmail.com
- update to 0.12.0
  * no changelog available
* Thu Aug 24 2017 jmatejek@suse.com
- singlespec auto-conversion
* Mon Aug 15 2016 toddrme2178@gmail.com
- Fix update-alternatives implementation.
* Thu May  7 2015 benoit.monin@gmx.fr
- update to 0.10.2:
  * no changelog available
- add python-setuptools and python-six as build dependencies
- add python-coverage, python-flake8 and python-nose as test
  dependencies
- add python-six as runtime dependency
- remove some failing tests which rely on find_and_load_cases
- run the tests via setup.py
- fix alternatives for lesscpy binary
* Sat Nov  8 2014 Led <ledest@gmail.com>
- fix bashism in pre script
* Mon Aug 12 2013 speilicke@suse.com
- Update to version 0.9j
  + Support for SVG stylesheets
  + Increased lessc compatibility
  + Many testing improvements
- Use update-alternatives
* Wed Jul 17 2013 speilicke@suse.com
- Update to version 0.9h
- Run testsuite
* Wed Feb 29 2012 saschpe@suse.de
- Initial version
